Description Usage Arguments Details Value References
The function applies the following steps to securities' rates of returns: A)
calculate abnormal returns for estimation_period(s), B) predict
abnormal returns for event period(s), C) aggregate the predicted abnormal
returns to cumulative abnormal return(s) for event_dates.
The package covers three models for the calculation of the cumulative abnomral returns:
- Mean-Adjusted Model (mean_adj)
- Market-Adjusted Model (mrkt_adj)
- Within-Sample Marekt-Adjusted Model (mrkt_adj_within)
This is the logic suggested by multiple scholars. See references below.
1 2 3 4 |
returns |
an object of |
regressor |
an object of the same class as |
event_dates |
an object of class |
estimation_period |
an object of class |
car_lag |
an object of class |
car_lead |
an object of class |
market_model |
market_model a character indicating the market model among
|
The generic function is dispatched for such classes as
zoo. (future versions of the package allow for classes of data.frame.)
If market_model is mrkt_adj or sim
and regressor has the length greater than one, the first element of
regressor will be applied for each security in returns.
an object of class data.frame which contains cumulative abnormal returns, the average cumulative abnormal return
(controls for varying event period durations if non-trading days are in the period), the number of tradingdays,
significance levels of the market-return-coefficient, significance level of the event-dummy-coefficient, and model fit (rquared) per securities per event date(s).
Note that significance levels and rsqared are NA if market model is mean_adj.
MacKinlay, A.C. Event Studies in Economics and Finance. Journal of Economic Literature, 35(1):13-39, 1997.
Brown S.J., Warner J.B. Using Daily Stock Returns, The Case of Event Studies. Journal of Financial Economics, 14:3-31, 1985.
Davies, R., Studnicka, Z. The heterogeneous impact of Brexit: Early indications from the FTSE. European Economic Review, 110:1-17, 2018.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.